OC.L10N.register(
    "groupfolders",
    {
    "Team folders" : "Тимски папки",
    "Denied (Inherited permission)" : "Забрането (наследена дозвола)",
    "Allowed (Inherited permission)" : "Овозможено (наследена дозвола)",
    "Denied" : "Забрането",
    "Allowed" : "Дозволено",
    "Access denied" : "Забранет пристап",
    "Access allowed" : "Овозможен пристап",
    "Inherit permission" : "Наследен пристап",
    "Deny" : "Забрани",
    "Allow" : "Дозволи",
    "Group" : "Група",
    "Team" : "Тим",
    "Team folder" : "Тимска папка",
    "Read" : "Читај",
    "Write" : "Пишувај",
    "Create" : "Креирај",
    "Delete" : "Избриши",
    "Share" : "Сподели",
    "You" : "Ти",
    "Remove access rule" : "Отстрани правило за пристап",
    "Select a user or group" : "Избери корисник или група",
    "Open Team folder" : "Отвори тимска папка",
    "List of Team folders." : "Листа на тимски папки.",
    "No Team folders yet" : "Сеуште нема тимски папки",
    "Team folders will show up here" : "Тимските папки ќе се појават овде",
    "Add group" : "Додади група",
    "Default" : "Предефиниран",
    "Unlimited" : "Неограничено",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Дали сте сигурни дека сакате да ја избришете \"{folderName}\" и сите датотеки внатре? Оваа операција не може да се врати",
    "Delete \"{folderName}\"?" : "Избриши \"{folderName}\"?",
    "Folder name" : "Име на папка",
    "Quota" : "Квота",
    "Advanced Permissions" : "Напредни дозволи",
    "Previous" : "Предходна",
    "Next" : "Следна",
    "User" : "Корисник",
    "Unknown" : "Непознат",
    "None" : "Ништо",
    "{size} used" : "искористено {size}",
    "Unset" : "Непоставено"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
